@@ -106,10 +106,10 @@ __midgard_connection_struct_free (MidgardConnection *self, gboolean object)
 	self->priv->cnc_str = NULL;
 
 	g_timer_stop (self->priv->timer);
-	gdouble bench = g_timer_elapsed (self->priv->timer, NULL);
+	/* gdouble bench = g_timer_elapsed (self->priv->timer, NULL); */
 
 	if (self->priv->loghandler) {
-		g_message ("MidgardConnection uptime %.04f seconds", bench);
+		/* g_message ("MidgardConnection uptime %.04f seconds", bench); */
 		g_log_remove_handler (G_LOG_DOMAIN, self->priv->loghandler);
 	}
 
