@@ -803,6 +803,10 @@ __insert_or_update_records(MgdObject *object, const gchar *tablename,
 	return inserted;
 }
 
+#define _CLEAR_OBJECT_GUID(object) \
+	g_free ((gchar *)MGD_OBJECT_GUID(object)); \
+	MGD_OBJECT_GUID(object) = NULL;
+
 /* Create object's data in storage */
 gboolean _midgard_object_create (	MgdObject *object,	
 					const gchar *create_guid,
@@ -816,13 +820,15 @@ gboolean _midgard_object_create (	MgdObject *object,
 	if (object->dbpriv->storage_data == NULL)
 		return FALSE;
 
-	/* TODO, we should jhandle such case when object has been created already 
-	 * and another create call is executed. Note, that import unserialized object is 
-	 * similiar scenario, so probably we need private is_fetched property */
-	/* if (MGD_OBJECT_GUID (object) != NULL){
-		g_warning("Can not create object. Already fetched from database"); 
+	/* Handle pure create call. If replicate is OBJECT_UPDATE_IMPORTED, then, 
+	 * object has guid already set, which is valid for unserialized object */
+	if (replicate == OBJECT_UPDATE_NONE && midgard_is_guid (MGD_OBJECT_GUID (object))) {
+      		midgard_set_error(mgd,
+				MGD_GENERIC_ERROR,
+				MGD_ERR_DUPLICATE,
+    				"Object already created.");
 		return FALSE;
-	} */
+	}
 
 	/* Create object's guid, only if it's not already set */
 	gchar *guid = NULL;
@@ -837,8 +843,10 @@ gboolean _midgard_object_create (	MgdObject *object,
 	}
 
 	/* check if object is valid */
-	if (!midgard_core_object_is_valid(object))
+	if (!midgard_core_object_is_valid(object)) {
+		_CLEAR_OBJECT_GUID (object);
 		return FALSE;
+	}
 	
 	MIDGARD_ERRNO_SET (MGD_OBJECT_CNC (object), MGD_ERR_OK);	
 
@@ -869,10 +877,12 @@ gboolean _midgard_object_create (	MgdObject *object,
 	gint is_dup = _object_in_tree(object);
 	if (is_dup == OBJECT_IN_TREE_DUPLICATE) {
 		MIDGARD_ERRNO_SET(MGD_OBJECT_CNC (object), MGD_ERR_DUPLICATE);
+		_CLEAR_OBJECT_GUID (object);
 		return FALSE;
 	}
 		
 	if (!midgard_quota_create(object)){
+		_CLEAR_OBJECT_GUID (object);
 		return FALSE;
 	}	
 
@@ -883,8 +893,7 @@ gboolean _midgard_object_create (	MgdObject *object,
 #endif
 	
 	if (inserted == -1) {
-		g_free((gchar *)MGD_OBJECT_GUID (object));
-		MGD_OBJECT_GUID (object) = g_strdup("");
+		_CLEAR_OBJECT_GUID (object);
 		MIDGARD_ERRNO_SET(MGD_OBJECT_CNC (object), MGD_ERR_INTERNAL);
 		return FALSE;
 	}
@@ -1006,7 +1015,10 @@ gboolean _midgard_object_create (	MgdObject *object,
  * Property registered with #MGD_TYPE_GUID doesn't hold valid guid ( MGD_ERR_INVALID_PROPERTY_VALUE ) 
  * </para></listitem>
  * <listitem><para>
- * Object's class is registered with tree facilities and there is already such object in midgard tree ( MGD_ERR_DUPLICATE ) 
+ * Object's class is registered with tree facilities and there is already object with the same name in midgard tree. ( MGD_ERR_DUPLICATE ) 
+ * </para></listitem>
+ * <listitem><para>
+ * Object has guid property set already. ( MGD_ERR_DUPLICATE ) 
  * </para></listitem>
  * <listitem><para>
  * Quota is activated and its limit is reached ( MGD_ERR_QUOTA ) 
@@ -2533,11 +2545,6 @@ gboolean midgard_object_purge(MgdObject *object)
 		return FALSE;
 	}	
 
-	/* TODO unlink midgard_blob for midgard_attachment */
-	/* Should we delete files here? These might be shared among many attachments */
-	if (g_str_equal(G_OBJECT_TYPE_NAME(object), "midgard_attachment"))
-		g_warning("Binary file is not unlinked! midgard_blob::delete not yet implemented");
-
 	dsql = g_string_new("DELETE ");
 	g_string_append_printf(dsql, "FROM %s WHERE guid='%s' ", table, guid);
 	
