@@ -41,20 +41,12 @@
 # include <unistd.h>
 #endif
 
-#ifdef HAVE_SECURITY_PAM_APPL_H
-# include <security/pam_appl.h>
-#else
-/* Mac OS X puts PAM headers into /usr/include/pam, not /usr/include/security */
-# ifdef HAVE_PAM_PAM_APPL_H
-#  include <pam/pam_appl.h>
-# endif
-#endif
-
 /* declarations for virtual methods */
 MidgardUser     	*__midgard_user_get               (MidgardConnection *mgd, guint n_params, const GParameter *parameters);
 MidgardUser     	**__midgard_user_query            (MidgardConnection *mgd, guint n_params, const GParameter *parameters);
 gboolean        	__midgard_user_create             (MidgardUser *self);
 gboolean        	__midgard_user_update             (MidgardUser *self);
+gboolean		__midgard_user_delete		  (MidgardUser *self);
 gboolean        	__midgard_user_is_user            (MidgardUser *self);
 gboolean        	__midgard_user_is_admin           (MidgardUser *self);
 MgdObject		*__midgard_user_get_person        (MidgardUser *self);
@@ -92,63 +84,6 @@ enum {
 	MIDGARD_USER_PERSON_GUID
 };
 
-/* PAM AUTH DATA */
-typedef struct {
-	const gchar *username;
-	const gchar *password;
-} midgard_auth_pam_appdata;
-
-#ifdef HAVE_LIBPAM
-
-// static gint _midgard_pam_conv(int num_msg, const struct pam_message **msg, 
-// 		struct pam_response **resp, void *appdata_ptr)
-// {
-// 	midgard_auth_pam_appdata *appdata = (midgard_auth_pam_appdata*) appdata_ptr;
-// 	int i = 0, j = 0;
-// 
-// 	if (num_msg && msg && *msg && resp && appdata_ptr) {
-// 		*resp = malloc(sizeof(struct pam_response)*num_msg);
-// 		if (*resp) {
-// 			/* Process conversation and fill in results */
-// 			for(; i < num_msg; i++) {
-// 				(*resp)[i].resp_retcode = 0;
-// 				(*resp)[i].resp = NULL;
-// 				switch((*msg)[i].msg_style) {
-// 					
-// 					case PAM_PROMPT_ECHO_ON: /* username */
-// 						(*resp)[i].resp = strdup(appdata->username);
-// 						break;
-// 					
-// 					case PAM_PROMPT_ECHO_OFF: /* password */
-// 						(*resp)[i].resp = strdup(appdata->password);
-// 						break;
-// 				}
-// 
-// 				/* If there was an error during strdup(), 
-// 				 * clean up already allocated  structures and return PAM_CONV_ERR */
-// 				if (!(*resp)[i].resp) {
-// 					for(j = i; j >= 0 ; j--) {
-// 						if ((*resp)[j].resp)
-// 							free((*resp)[j].resp);
-// 					}
-// 					free(*resp);
-// 					*resp = NULL;
-// 					g_debug("Return PAM_CONV_ERROR due to strdup() failure");
-// 					return PAM_CONV_ERR;
-// 				}
-// 			}
-// 			g_debug("Return PAM_SUCCESS");
-// 			return PAM_SUCCESS;
-// 		}
-// 	}
-// 	g_debug("Return PAM_CONV_ERROR");
-// 	return PAM_CONV_ERR;
-// }
-
-#endif /* HAVE_LIBPAM */
-
-/* PAM AUTH DATA END */
-
 static gchar *
 __string2md5hash (const gchar *str) 
 {
@@ -735,6 +670,81 @@ __midgard_user_update (MidgardUser *self)
 	return FALSE;
 }
 
+/**
+ * midgard_user_delete:
+ * @self: #MidgardUser instance
+ *
+ * Delete user's storage record.
+ * 
+ * Cases to return %FALSE:
+ * <itemizedlist>
+ * <listitem><para>
+ * User's guid is not set ( MGD_ERR_INVALID_PROPERTY_VALUE )
+ * </para></listitem>
+ * <listitem><para>
+ * Failed to delete storage record ( MGD_ERR_INTERNAL )
+ * </para></listitem>
+ * </itemizedlist>
+ *
+ * Returns: @TRUE on success, @FALSE otherwise
+ *
+ * Since: 9.09.2
+ */ 
+gboolean 
+midgard_user_delete (MidgardUser *self)
+{
+	g_return_val_if_fail (self != NULL, FALSE);
+
+	MidgardUserClass *klass = MIDGARD_USER_GET_CLASS (self);
+	return klass->delete_record (self);
+}
+
+gboolean 
+__midgard_user_delete (MidgardUser *self)
+{
+	g_return_val_if_fail (self != NULL, FALSE);
+	g_return_val_if_fail (MIDGARD_IS_USER (self), FALSE);
+	
+	MidgardConnection *mgd = MGD_OBJECT_CNC (self);
+	const gchar *guid = MGD_OBJECT_GUID (self);
+
+	g_return_val_if_fail (mgd != NULL, FALSE);
+
+	MIDGARD_ERRNO_SET (mgd, MGD_ERR_OK);
+
+	/* Validate guid */
+	if (!guid
+		|| (*guid && *guid == '\0')
+ 		|| (guid && !midgard_is_guid (guid))) {
+
+		MIDGARD_ERRNO_SET_STRING (mgd, MGD_ERR_INVALID_PROPERTY_VALUE, "Invalid guid value");
+		return FALSE;
+	}
+
+	GString *del_query = g_string_new ("DELETE FROM midgard_user WHERE ");
+	g_string_append_printf (del_query, "guid='%s'", guid);
+
+      	g_debug ("%s", del_query->str);
+
+	GError *error = NULL;
+	GdaConnection *connection = mgd->priv->connection;
+	GdaCommand *command = gda_command_new (del_query->str, GDA_COMMAND_TYPE_SQL, GDA_COMMAND_OPTION_STOP_ON_ERRORS);
+	gda_connection_execute_non_select_command (connection, command, NULL, &error);
+	gda_command_free (command);
+	g_string_free (del_query, TRUE);
+	
+	if(error){
+		g_clear_error(&error);
+		return FALSE;
+	}
+
+	/* Set empty guid */
+	g_free ((gchar *)self->dbpriv->guid);
+	self->dbpriv->guid = NULL;
+
+	return TRUE;
+}
+
 /** 
  * midgard_user_login:
  * @self: #MidgardUser instance
@@ -1573,6 +1583,7 @@ static void _midgard_user_class_init(
 	klass->query = __midgard_user_query;
 	klass->create = __midgard_user_create;
 	klass->update = __midgard_user_update;
+	klass->delete_record = __midgard_user_delete;
 	klass->is_user = __midgard_user_is_user;
 	klass->is_admin = __midgard_user_is_admin;
 
