@@ -60,6 +60,14 @@ struct MidgardQueryBuilderClass{
 	void 		(*include_deleted) 	(MidgardQueryBuilder *builder);
 	GObject 	**(*execute) 		(MidgardQueryBuilder *builder, guint *n_objects);
 	guint 		(*count) 		(MidgardQueryBuilder *builder);
+
+	/* signals */
+	void 		(*execution_start)	(GObject *object);
+	void		(*execution_end)		(GObject *object);
+
+	/* signals IDs */
+	guint 		signal_id_execution_start;
+	guint		signal_id_execution_end;
 };
 
 GType			midgard_query_builder_get_type		(void);
