@@ -26,6 +26,7 @@
 #include "midgard_object_class.h"
 #include "midgard_tree.h"
 #include <libgda/libgda.h>
+#include "midgard_core_query.h"
 
 static void add_sql(MidgardQueryConstraint *constraint, GString *sql) {
         g_assert(constraint);
@@ -191,18 +192,22 @@ static void __condition_append_value(GString *str,
 		MidgardQueryConstraint *constraint, GValue *value)
 {
 	gchar *escaped;
+	MidgardConnection *mgd = NULL;
+	if (constraint->priv->builder)
+		mgd = constraint->priv->builder->priv->mgd;
+
 	if(value == NULL)
 		value = constraint->priv->value;
 
 	switch(G_VALUE_TYPE(value)) {
 
 		case G_TYPE_STRING:
-			escaped =
-				gda_connection_value_to_sql_string(
-						constraint->priv->builder->priv->mgd->priv->connection,
-						value);
-			g_string_append_printf(str, "%s", escaped);
-			g_free(escaped);
+			if (mgd)
+				escaped = midgard_core_query_escape_string (mgd, g_value_get_string (value));
+			else 
+				escaped = gda_default_escape_string (g_value_get_string (value));
+			g_string_append_printf(str, "'%s'", escaped);
+			g_free (escaped);
 			break;
 
 		case G_TYPE_UINT:
@@ -466,8 +471,10 @@ midgard_query_constraint_private_new (void)
 {
 	MidgardQueryConstraintPrivate *priv = g_new (MidgardQueryConstraintPrivate, 1);
 	
-	priv->prop_left = midgard_core_schema_type_property_attr_new();
-	priv->prop_right = midgard_core_schema_type_property_attr_new();
+	/* Initialize empty property attr. We need only pointers. */
+	priv->prop_left = midgard_core_schema_type_property_attr_new_empty();
+	priv->prop_right = midgard_core_schema_type_property_attr_new_empty();
+
 	priv->condition_operator = NULL;
 	priv->joins = NULL;
 	priv->condition = NULL;
@@ -490,12 +497,9 @@ void midgard_query_constraint_private_free(MidgardQueryConstraintPrivate *mqcp)
 {
 	g_assert(mqcp != NULL);
 
-	g_free(mqcp->prop_left);
-	g_free(mqcp->prop_right);
-	/* PropertyAttr doesn't initialize new types so it's safe to call g_free*/
-	/* _mgd_schema_property_attr_free(mqcp->prop_left);
-	_mgd_schema_property_attr_free(mqcp->prop_right);
-	*/
+	/* Just free structures, they are initialized empty. */
+	g_free (mqcp->prop_left);
+	g_free (mqcp->prop_right);
 	
 	if(mqcp->condition_operator != NULL)
 		g_free(mqcp->condition_operator);
